/*

Fenryxo's library :-)

Copyright 2011 Jiří Janoušek <janousek.jiri@gmail.com>

If this file is built as a shared library it's released under GNU LGPL 3+ and 2-Clause BSD.
Otherwise it's released under GNU GPL 3+.
 
This program is distributed in the hope that it will be useful, but 
WITHOUT ANY WARRANTY; without even the implied warranties of 
MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
PURPOSE.  See <http://www.gnu.org/licenses/> for more details.
*/

namespace Fenryxo.Path{
	/**
	 * Search user data directory and system data directories for subdirectories.
	 * 
	 * @param name name of subdirectory
	 * @return Existing subdirectories or empty array in no subdirectory has been found.
	 */
	public static File[] get_data_dirs(string name){
		File[] dirs = {};
		File dir = File.new_for_path(Environment.get_user_data_dir()).get_child(name);
		if(dir.query_file_type(0) == FileType.DIRECTORY) dirs += dir;
		foreach(string path in Environment.get_system_data_dirs()){
			dir = File.new_for_path(path).get_child(name);
			if(dir.query_file_type(0) == FileType.DIRECTORY) dirs += dir;
		}
		return dirs;
	}
	
	/**
	 * Search user data directory and system data directories for subdirectory.
	 * 
	 * @param name name of subdirectory
	 * @return First existing subdirectory or null in no subdirectory has been found.
	 */
	public static File? get_data_dir(string name){
		File dir = File.new_for_path(Environment.get_user_data_dir()).get_child(name);
		if(dir.query_file_type(0) == FileType.DIRECTORY) return dir;
		foreach(string path in Environment.get_system_data_dirs()){
			dir = File.new_for_path(path).get_child(name);
			if(dir.query_file_type(0) == FileType.DIRECTORY) return dir;
		}
		return null;
	}
	
	/**
	 * Search user data directory and system data directories for file.
	 * 
	 * @param name name of the file
	 * @return First existing file or null in no file has been found.
	 * @todo unit testing
	 */
	public static File? get_data_file(string name){
		File f = File.new_for_path(Environment.get_user_data_dir()).get_child(name);
		if(f.query_file_type(0) == FileType.REGULAR) return f;
		foreach(string path in Environment.get_system_data_dirs()){
			f = File.new_for_path(path).get_child(name);
			if(f.query_file_type(0) == FileType.REGULAR) return f;
		}
		return null;
	}
	
	/**
	 * Returns default configuration file within given subdirectory and with given name
	 * 
	 * @param dir subdirectory name
	 * @param file file name
	 */
	public static File get_default_config_file(string dir, string file){
		return File.new_for_path(Environment.get_user_config_dir())
			.get_child(dir).get_child(file);
	}
	
	/**
	 * Returns default cache file within given subdirectory and with given name
	 * 
	 * @param dir subdirectory name
	 * @param file file name
	 */
	public static File get_default_cache_file(string dir, string file){
		return File.new_for_path(Environment.get_user_cache_dir())
			.get_child(dir).get_child(file);
	}
}
