/*

Fenryxo's library :-)

Copyright 2011 Jiří Janoušek <janousek.jiri@gmail.com>

If this file is built as a shared library it's released under GNU LGPL 3+ and 2-Clause BSD.
Otherwise it's released under GNU GPL 3+.
 
This program is distributed in the hope that it will be useful, but 
WITHOUT ANY WARRANTY; without even the implied warranties of 
MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
PURPOSE.  See <http://www.gnu.org/licenses/> for more details.
*/

namespace Fenryxo.Widgets{
	/**
	 * Simple Error dialog with OK button.
	 */
	public class ErrorDialog: Gtk.MessageDialog{
		
		/**
		 * Constructs new error dialog.
		 * 
		 * @param title Title of the error message (not title of the dialog)
		 * @param message Text of the error message
		 */
		public ErrorDialog(string title, string message){
			Object(
				title: "",
				modal: true,
				message_type: Gtk.MessageType.ERROR,
				buttons: Gtk.ButtonsType.OK
			);
			this.text = title;
			this.secondary_text = message;
		}
		
		public override void response(int id){
			this.destroy();
		}
	}
	
	/**
	 * Simple confirmation dialog with YES and NO buttons.
	 */
	public class ConfirmDialog: Gtk.MessageDialog{
		
		/**
		 * Constructs new error dialog.
		 * 
		 * @param title Title of the error message (not title of the dialog)
		 * @param message Text of the error message
		 */
		public ConfirmDialog(string title, string message){
			Object(
				title: "",
				modal: true,
				message_type: Gtk.MessageType.QUESTION,
				buttons: Gtk.ButtonsType.YES_NO
			);
			this.text = title;
			this.secondary_text = message;
		}
		
		public override void response(int id){
			this.destroy();
		}
	}
	
	 /**
     * Button with stock icon and custom label
     */
    public class ImageLinkButton: Gtk.LinkButton{
		/**
		 * Create new button with stock icon and custom label
		 * @param stock Stock id for icon
		 * @param label text on the button
		 */
		public ImageLinkButton(string image, string uri, string label){
			Object(label: label, uri: uri);
			xalign = 0.5f;
			yalign = 0.5f;
			var box = new Gtk.VBox(false, 5);
			var child = this.get_child();
			this.remove(child);
			var img = new Gtk.Image.from_file(image);
			box.pack_start(img, false, false);
			box.pack_start(child, true, true);
			this.add(box);
			box.show_all();
		}
	}
	
}
